==> arnie-0.2.22.tgz: package/lib/operators/forEach.test.js <==
'use strict';

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _taggedTemplateLiteral2 = require('babel-runtime/helpers/taggedTemplateLiteral');

var _taggedTemplateLiteral3 = _interopRequireDefault(_taggedTemplateLiteral2);

var _templateObject = (0, _taggedTemplateLiteral3.default)(['list'], ['list']);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var t = require('tap');
var A = require('../');
var arnie = A();
var input = require('../tags/input');
var forEach = require('./forEach');

t.test('Operator: forEach', function (t) {
  t.plan(8);

  var num = 0;
  var task = [forEach(input(_templateObject), 'item', [function (_ref) {
    var input = _ref.input;

    return new _promise2.default(function (resolve, reject) {
      setTimeout(function () {
        num += 1;
        t.assert(input.item, 'should pass iterated object');
        t.pass('should execute a new function-tree for iteration ' + num + '/2');
        t.assert(input.deep.param.value === 1, 'should use isolated payload for iteration ' + num + '/2');
        input.deep.param.value += 1;
        resolve(input);
      }, Math.random() * 300 + 50);
    });
  }]), function (_ref2) {
    var input = _ref2.input;

    t.assert(num === 2, 'finish iteration before next action');
    t.assert(input.deep.param.value === 1, 'should use isolated payload');
  }];

  var payload = {
    list: [1, 2],
    deep: { param: { value: 1 } }
  };
  arnie(task, payload).catch(console.error);
});

==> arnie-0.3.8.tgz: package/lib/operators/forEach.test.js <==
'use strict';

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _taggedTemplateLiteral2 = require('babel-runtime/helpers/taggedTemplateLiteral');

var _taggedTemplateLiteral3 = _interopRequireDefault(_taggedTemplateLiteral2);

var _templateObject = (0, _taggedTemplateLiteral3.default)(['list'], ['list']);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var t = require('tap');
var A = require('../');
var arnie = A();
var props = require('../tags/props');
var forEach = require('./forEach');

t.test('Operator: forEach', function (t) {
  t.plan(8);

  var num = 0;
  var task = [forEach(props(_templateObject), 'item', [function (_ref) {
    var props = _ref.props;

    return new _promise2.default(function (resolve, reject) {
      setTimeout(function () {
        num += 1;
        t.assert(props.item, 'should pass iterated object');
        t.pass('should execute a new function-tree for iteration ' + num + '/2');
        t.assert(props.deep.param.value === 1, 'should use isolated payload for iteration ' + num + '/2');
        props.deep.param.value += 1;
        resolve(props);
      }, Math.random() * 300 + 50);
    });
  }]), function (_ref2) {
    var props = _ref2.props;

    t.assert(num === 2, 'finish iteration before next action');
    t.assert(props.deep.param.value === 1, 'should use isolated payload');
  }];

  var payload = {
    list: [1, 2],
    deep: { param: { value: 1 } }
  };
  arnie(task, payload).catch(console.error);
});
